@@ -4,7 +4,7 @@
 
 #include <libtasn1.h>
 
-const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
+const asn1_static_node pkix_asn1_tab[] = {
   { "PKIX1Implicit88", 536875024, NULL },
   { NULL, 1610612748, NULL },
   { "iso", 1073741825, "1"},
@@ -52,9 +52,9 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { NULL, 1073741825, "id-ce"},
   { NULL, 1, "16"},
   { "PrivateKeyUsagePeriod", 1610612741, NULL },
-  { "notBefore", 1619025937, NULL },
+  { "notBefore", 1610637349, NULL },
   { NULL, 4104, "0"},
-  { "notAfter", 545284113, NULL },
+  { "notAfter", 536895525, NULL },
   { NULL, 4104, "1"},
   { "id-ce-certificatePolicies", 1879048204, NULL },
   { NULL, 1073741825, "id-ce"},
@@ -73,7 +73,7 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "qualifier", 541065229, NULL },
   { "policyQualifierId", 1, NULL },
   { "PolicyQualifierId", 1073741836, NULL },
-  { "CPSuri", 1073741826, "IA5String"},
+  { "CPSuri", 1073741853, NULL },
   { "UserNotice", 1610612741, NULL },
   { "noticeRef", 1073758210, "NoticeReference"},
   { "explicitText", 16386, "DisplayText"},
@@ -82,11 +82,11 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "noticeNumbers", 536870923, NULL },
   { NULL, 3, NULL },
   { "DisplayText", 1610612754, NULL },
-  { "visibleString", 1612709890, "VisibleString"},
+  { "visibleString", 1612709923, NULL },
   { "200", 524298, "1"},
-  { "bmpString", 1612709890, "BMPString"},
+  { "bmpString", 1612709921, NULL },
   { "200", 524298, "1"},
-  { "utf8String", 538968066, "UTF8String"},
+  { "utf8String", 538968098, NULL },
   { "200", 524298, "1"},
   { "id-ce-policyMappings", 1879048204, NULL },
   { NULL, 1073741825, "id-ce"},
@@ -106,9 +106,9 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "GeneralName", 1610612754, NULL },
   { "otherName", 1610620930, "AnotherName"},
   { NULL, 4104, "0"},
-  { "rfc822Name", 1610620930, "IA5String"},
+  { "rfc822Name", 1610620957, NULL },
   { NULL, 4104, "1"},
-  { "dNSName", 1610620930, "IA5String"},
+  { "dNSName", 1610620957, NULL },
   { NULL, 4104, "2"},
   { "x400Address", 1610620930, "ORAddress"},
   { NULL, 4104, "3"},
@@ -116,7 +116,7 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { NULL, 4104, "4"},
   { "ediPartyName", 1610620930, "EDIPartyName"},
   { NULL, 4104, "5"},
-  { "uniformResourceIdentifier", 1610620930, "IA5String"},
+  { "uniformResourceIdentifier", 1610620957, NULL },
   { NULL, 4104, "6"},
   { "iPAddress", 1610620935, NULL },
   { NULL, 4104, "7"},
@@ -310,7 +310,7 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "id-ce-invalidityDate", 1879048204, NULL },
   { NULL, 1073741825, "id-ce"},
   { NULL, 1, "24"},
-  { "InvalidityDate", 1082130449, NULL },
+  { "InvalidityDate", 1073741861, NULL },
   { "VisibleString", 1610620935, NULL },
   { NULL, 4360, "26"},
   { "NumericString", 1610620935, NULL },
@@ -388,108 +388,108 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { NULL, 1073741825, "id-at"},
   { NULL, 1, "44"},
   { "X520name", 1610612754, NULL },
-  { "teletexString", 1612709890, "TeletexString"},
+  { "teletexString", 1612709918, NULL },
   { "ub-name", 524298, "1"},
-  { "printableString", 1612709890, "PrintableString"},
+  { "printableString", 1612709919, NULL },
   { "ub-name", 524298, "1"},
-  { "universalString", 1612709890, "UniversalString"},
+  { "universalString", 1612709920, NULL },
   { "ub-name", 524298, "1"},
-  { "utf8String", 1612709890, "UTF8String"},
+  { "utf8String", 1612709922, NULL },
   { "ub-name", 524298, "1"},
-  { "bmpString", 538968066, "BMPString"},
+  { "bmpString", 538968097, NULL },
   { "ub-name", 524298, "1"},
   { "id-at-commonName", 1880096780, "AttributeType"},
   { NULL, 1073741825, "id-at"},
   { NULL, 1, "3"},
   { "X520CommonName", 1610612754, NULL },
-  { "teletexString", 1612709890, "TeletexString"},
+  { "teletexString", 1612709918, NULL },
   { "ub-common-name", 524298, "1"},
-  { "printableString", 1612709890, "PrintableString"},
+  { "printableString", 1612709919, NULL },
   { "ub-common-name", 524298, "1"},
-  { "universalString", 1612709890, "UniversalString"},
+  { "universalString", 1612709920, NULL },
   { "ub-common-name", 524298, "1"},
-  { "utf8String", 1612709890, "UTF8String"},
+  { "utf8String", 1612709922, NULL },
   { "ub-common-name", 524298, "1"},
-  { "bmpString", 538968066, "BMPString"},
+  { "bmpString", 538968097, NULL },
   { "ub-common-name", 524298, "1"},
   { "id-at-localityName", 1880096780, "AttributeType"},
   { NULL, 1073741825, "id-at"},
   { NULL, 1, "7"},
   { "X520LocalityName", 1610612754, NULL },
-  { "teletexString", 1612709890, "TeletexString"},
+  { "teletexString", 1612709918, NULL },
   { "ub-locality-name", 524298, "1"},
-  { "printableString", 1612709890, "PrintableString"},
+  { "printableString", 1612709919, NULL },
   { "ub-locality-name", 524298, "1"},
-  { "universalString", 1612709890, "UniversalString"},
+  { "universalString", 1612709920, NULL },
   { "ub-locality-name", 524298, "1"},
-  { "utf8String", 1612709890, "UTF8String"},
+  { "utf8String", 1612709922, NULL },
   { "ub-locality-name", 524298, "1"},
-  { "bmpString", 538968066, "BMPString"},
+  { "bmpString", 538968097, NULL },
   { "ub-locality-name", 524298, "1"},
   { "id-at-stateOrProvinceName", 1880096780, "AttributeType"},
   { NULL, 1073741825, "id-at"},
   { NULL, 1, "8"},
   { "X520StateOrProvinceName", 1610612754, NULL },
-  { "teletexString", 1612709890, "TeletexString"},
+  { "teletexString", 1612709918, NULL },
   { "ub-state-name", 524298, "1"},
-  { "printableString", 1612709890, "PrintableString"},
+  { "printableString", 1612709919, NULL },
   { "ub-state-name", 524298, "1"},
-  { "universalString", 1612709890, "UniversalString"},
+  { "universalString", 1612709920, NULL },
   { "ub-state-name", 524298, "1"},
-  { "utf8String", 1612709890, "UTF8String"},
+  { "utf8String", 1612709922, NULL },
   { "ub-state-name", 524298, "1"},
-  { "bmpString", 538968066, "BMPString"},
+  { "bmpString", 538968097, NULL },
   { "ub-state-name", 524298, "1"},
   { "id-at-organizationName", 1880096780, "AttributeType"},
   { NULL, 1073741825, "id-at"},
   { NULL, 1, "10"},
   { "X520OrganizationName", 1610612754, NULL },
-  { "teletexString", 1612709890, "TeletexString"},
+  { "teletexString", 1612709918, NULL },
   { "ub-organization-name", 524298, "1"},
-  { "printableString", 1612709890, "PrintableString"},
+  { "printableString", 1612709919, NULL },
   { "ub-organization-name", 524298, "1"},
-  { "universalString", 1612709890, "UniversalString"},
+  { "universalString", 1612709920, NULL },
   { "ub-organization-name", 524298, "1"},
-  { "utf8String", 1612709890, "UTF8String"},
+  { "utf8String", 1612709922, NULL },
   { "ub-organization-name", 524298, "1"},
-  { "bmpString", 538968066, "BMPString"},
+  { "bmpString", 538968097, NULL },
   { "ub-organization-name", 524298, "1"},
   { "id-at-organizationalUnitName", 1880096780, "AttributeType"},
   { NULL, 1073741825, "id-at"},
   { NULL, 1, "11"},
   { "X520OrganizationalUnitName", 1610612754, NULL },
-  { "teletexString", 1612709890, "TeletexString"},
+  { "teletexString", 1612709918, NULL },
   { "ub-organizational-unit-name", 524298, "1"},
-  { "printableString", 1612709890, "PrintableString"},
+  { "printableString", 1612709919, NULL },
   { "ub-organizational-unit-name", 524298, "1"},
-  { "universalString", 1612709890, "UniversalString"},
+  { "universalString", 1612709920, NULL },
   { "ub-organizational-unit-name", 524298, "1"},
-  { "utf8String", 1612709890, "UTF8String"},
+  { "utf8String", 1612709922, NULL },
   { "ub-organizational-unit-name", 524298, "1"},
-  { "bmpString", 538968066, "BMPString"},
+  { "bmpString", 538968097, NULL },
   { "ub-organizational-unit-name", 524298, "1"},
   { "id-at-title", 1880096780, "AttributeType"},
   { NULL, 1073741825, "id-at"},
   { NULL, 1, "12"},
   { "X520Title", 1610612754, NULL },
-  { "teletexString", 1612709890, "TeletexString"},
+  { "teletexString", 1612709918, NULL },
   { "ub-title", 524298, "1"},
-  { "printableString", 1612709890, "PrintableString"},
+  { "printableString", 1612709919, NULL },
   { "ub-title", 524298, "1"},
-  { "universalString", 1612709890, "UniversalString"},
+  { "universalString", 1612709920, NULL },
   { "ub-title", 524298, "1"},
-  { "utf8String", 1612709890, "UTF8String"},
+  { "utf8String", 1612709922, NULL },
   { "ub-title", 524298, "1"},
-  { "bmpString", 538968066, "BMPString"},
+  { "bmpString", 538968097, NULL },
   { "ub-title", 524298, "1"},
   { "id-at-dnQualifier", 1880096780, "AttributeType"},
   { NULL, 1073741825, "id-at"},
   { NULL, 1, "46"},
-  { "X520dnQualifier", 1073741826, "PrintableString"},
+  { "X520dnQualifier", 1073741855, NULL },
   { "id-at-countryName", 1880096780, "AttributeType"},
   { NULL, 1073741825, "id-at"},
   { NULL, 1, "6"},
-  { "X520countryName", 1612709890, "PrintableString"},
+  { "X520countryName", 1612709919, NULL },
   { NULL, 1048586, "2"},
   { "pkcs-9", 1879048204, NULL },
   { "iso", 1073741825, "1"},
@@ -501,7 +501,7 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "emailAddress", 1880096780, "AttributeType"},
   { NULL, 1073741825, "pkcs-9"},
   { NULL, 1, "1"},
-  { "Pkcs9email", 1612709890, "IA5String"},
+  { "Pkcs9email", 1612709917, NULL },
   { "ub-emailaddress-length", 524298, "1"},
   { "Name", 1610612754, NULL },
   { "rdnSequence", 2, "RDNSequence"},
@@ -512,15 +512,15 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "MAX", 1074266122, "1"},
   { NULL, 2, "AttributeTypeAndValue"},
   { "DirectoryString", 1610612754, NULL },
-  { "teletexString", 1612709890, "TeletexString"},
+  { "teletexString", 1612709918, NULL },
   { "MAX", 524298, "1"},
-  { "printableString", 1612709890, "PrintableString"},
+  { "printableString", 1612709919, NULL },
   { "MAX", 524298, "1"},
-  { "universalString", 1612709890, "UniversalString"},
+  { "universalString", 1612709920, NULL },
   { "MAX", 524298, "1"},
-  { "utf8String", 1612709890, "UTF8String"},
+  { "utf8String", 1612709922, NULL },
   { "MAX", 524298, "1"},
-  { "bmpString", 538968066, "BMPString"},
+  { "bmpString", 538968097, NULL },
   { "MAX", 524298, "1"},
   { "Certificate", 1610612741, NULL },
   { "tbsCertificate", 1073741826, "TBSCertificate"},
@@ -551,8 +551,8 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "notBefore", 1073741826, "Time"},
   { "notAfter", 2, "Time"},
   { "Time", 1610612754, NULL },
-  { "utcTime", 1090519057, NULL },
-  { "generalTime", 8388625, NULL },
+  { "utcTime", 1073741860, NULL },
+  { "generalTime", 37, NULL },
   { "UniqueIdentifier", 1073741830, NULL },
   { "SubjectPublicKeyInfo", 1610612741, NULL },
   { "algorithm", 1073741826, "AlgorithmIdentifier"},
@@ -665,55 +665,55 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { NULL, 2056, "6"},
   { "CountryName", 1610620946, NULL },
   { NULL, 1073746952, "1"},
-  { "x121-dcc-code", 1612709890, "NumericString"},
+  { "x121-dcc-code", 1612709916, NULL },
   { NULL, 1048586, "ub-country-name-numeric-length"},
-  { "iso-3166-alpha2-code", 538968066, "PrintableString"},
+  { "iso-3166-alpha2-code", 538968095, NULL },
   { NULL, 1048586, "ub-country-name-alpha-length"},
   { "AdministrationDomainName", 1610620946, NULL },
   { NULL, 1073744904, "2"},
-  { "numeric", 1612709890, "NumericString"},
+  { "numeric", 1612709916, NULL },
   { "ub-domain-name-length", 524298, "0"},
-  { "printable", 538968066, "PrintableString"},
+  { "printable", 538968095, NULL },
   { "ub-domain-name-length", 524298, "0"},
   { "NetworkAddress", 1073741826, "X121Address"},
-  { "X121Address", 1612709890, "NumericString"},
+  { "X121Address", 1612709916, NULL },
   { "ub-x121-address-length", 524298, "1"},
-  { "TerminalIdentifier", 1612709890, "PrintableString"},
+  { "TerminalIdentifier", 1612709919, NULL },
   { "ub-terminal-id-length", 524298, "1"},
   { "PrivateDomainName", 1610612754, NULL },
-  { "numeric", 1612709890, "NumericString"},
+  { "numeric", 1612709916, NULL },
   { "ub-domain-name-length", 524298, "1"},
-  { "printable", 538968066, "PrintableString"},
+  { "printable", 538968095, NULL },
   { "ub-domain-name-length", 524298, "1"},
-  { "OrganizationName", 1612709890, "PrintableString"},
+  { "OrganizationName", 1612709919, NULL },
   { "ub-organization-name-length", 524298, "1"},
-  { "NumericUserIdentifier", 1612709890, "NumericString"},
+  { "NumericUserIdentifier", 1612709916, NULL },
   { "ub-numeric-user-id-length", 524298, "1"},
   { "PersonalName", 1610612750, NULL },
-  { "surname", 1814044674, "PrintableString"},
+  { "surname", 1814044703, NULL },
   { NULL, 1073745928, "0"},
   { "ub-surname-length", 524298, "1"},
-  { "given-name", 1814061058, "PrintableString"},
+  { "given-name", 1814061087, NULL },
   { NULL, 1073745928, "1"},
   { "ub-given-name-length", 524298, "1"},
-  { "initials", 1814061058, "PrintableString"},
+  { "initials", 1814061087, NULL },
   { NULL, 1073745928, "2"},
   { "ub-initials-length", 524298, "1"},
-  { "generation-qualifier", 740319234, "PrintableString"},
+  { "generation-qualifier", 740319263, NULL },
   { NULL, 1073745928, "3"},
   { "ub-generation-qualifier-length", 524298, "1"},
   { "OrganizationalUnitNames", 1612709899, NULL },
   { "ub-organizational-units", 1074266122, "1"},
   { NULL, 2, "OrganizationalUnitName"},
-  { "OrganizationalUnitName", 1612709890, "PrintableString"},
+  { "OrganizationalUnitName", 1612709919, NULL },
   { "ub-organizational-unit-name-length", 524298, "1"},
   { "BuiltInDomainDefinedAttributes", 1612709899, NULL },
   { "ub-domain-defined-attributes", 1074266122, "1"},
   { NULL, 2, "BuiltInDomainDefinedAttribute"},
   { "BuiltInDomainDefinedAttribute", 1610612741, NULL },
-  { "type", 1612709890, "PrintableString"},
+  { "type", 1612709919, NULL },
   { "ub-domain-defined-attribute-type-length", 524298, "1"},
-  { "value", 538968066, "PrintableString"},
+  { "value", 538968095, NULL },
   { "ub-domain-defined-attribute-value-length", 524298, "1"},
   { "ExtensionAttributes", 1612709903, NULL },
   { "ub-extension-attributes", 1074266122, "1"},
@@ -726,48 +726,48 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { NULL, 1073743880, "1"},
   { "extension-attribute-type", 1, NULL },
   { "common-name", 1342177283, "1"},
-  { "CommonName", 1612709890, "PrintableString"},
+  { "CommonName", 1612709919, NULL },
   { "ub-common-name-length", 524298, "1"},
   { "teletex-common-name", 1342177283, "2"},
-  { "TeletexCommonName", 1612709890, "TeletexString"},
+  { "TeletexCommonName", 1612709918, NULL },
   { "ub-common-name-length", 524298, "1"},
   { "teletex-organization-name", 1342177283, "3"},
-  { "TeletexOrganizationName", 1612709890, "TeletexString"},
+  { "TeletexOrganizationName", 1612709918, NULL },
   { "ub-organization-name-length", 524298, "1"},
   { "teletex-personal-name", 1342177283, "4"},
   { "TeletexPersonalName", 1610612750, NULL },
-  { "surname", 1814044674, "TeletexString"},
+  { "surname", 1814044702, NULL },
   { NULL, 1073743880, "0"},
   { "ub-surname-length", 524298, "1"},
-  { "given-name", 1814061058, "TeletexString"},
+  { "given-name", 1814061086, NULL },
   { NULL, 1073743880, "1"},
   { "ub-given-name-length", 524298, "1"},
-  { "initials", 1814061058, "TeletexString"},
+  { "initials", 1814061086, NULL },
   { NULL, 1073743880, "2"},
   { "ub-initials-length", 524298, "1"},
-  { "generation-qualifier", 740319234, "TeletexString"},
+  { "generation-qualifier", 740319262, NULL },
   { NULL, 1073743880, "3"},
   { "ub-generation-qualifier-length", 524298, "1"},
   { "teletex-organizational-unit-names", 1342177283, "5"},
   { "TeletexOrganizationalUnitNames", 1612709899, NULL },
   { "ub-organizational-units", 1074266122, "1"},
   { NULL, 2, "TeletexOrganizationalUnitName"},
-  { "TeletexOrganizationalUnitName", 1612709890, "TeletexString"},
+  { "TeletexOrganizationalUnitName", 1612709918, NULL },
   { "ub-organizational-unit-name-length", 524298, "1"},
   { "pds-name", 1342177283, "7"},
-  { "PDSName", 1612709890, "PrintableString"},
+  { "PDSName", 1612709919, NULL },
   { "ub-pds-name-length", 524298, "1"},
   { "physical-delivery-country-name", 1342177283, "8"},
   { "PhysicalDeliveryCountryName", 1610612754, NULL },
-  { "x121-dcc-code", 1612709890, "NumericString"},
+  { "x121-dcc-code", 1612709916, NULL },
   { NULL, 1048586, "ub-country-name-numeric-length"},
-  { "iso-3166-alpha2-code", 538968066, "PrintableString"},
+  { "iso-3166-alpha2-code", 538968095, NULL },
   { NULL, 1048586, "ub-country-name-alpha-length"},
   { "postal-code", 1342177283, "9"},
   { "PostalCode", 1610612754, NULL },
-  { "numeric-code", 1612709890, "NumericString"},
+  { "numeric-code", 1612709916, NULL },
   { "ub-postal-code-length", 524298, "1"},
-  { "printable-code", 538968066, "PrintableString"},
+  { "printable-code", 538968095, NULL },
   { "ub-postal-code-length", 524298, "1"},
   { "physical-delivery-office-name", 1342177283, "10"},
   { "PhysicalDeliveryOfficeName", 1073741826, "PDSParameter"},
@@ -785,9 +785,9 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "UnformattedPostalAddress", 1610612750, NULL },
   { "printable-address", 1814052875, NULL },
   { "ub-pds-physical-address-lines", 1074266122, "1"},
-  { NULL, 538968066, "PrintableString"},
+  { NULL, 538968095, NULL },
   { "ub-pds-parameter-length", 524298, "1"},
-  { "teletex-string", 740311042, "TeletexString"},
+  { "teletex-string", 740311070, NULL },
   { "ub-unformatted-address-length", 524298, "1"},
   { "street-address", 1342177283, "17"},
   { "StreetAddress", 1073741826, "PDSParameter"},
@@ -800,17 +800,17 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "local-postal-attributes", 1342177283, "21"},
   { "LocalPostalAttributes", 1073741826, "PDSParameter"},
   { "PDSParameter", 1610612750, NULL },
-  { "printable-string", 1814052866, "PrintableString"},
+  { "printable-string", 1814052895, NULL },
   { "ub-pds-parameter-length", 524298, "1"},
-  { "teletex-string", 740311042, "TeletexString"},
+  { "teletex-string", 740311070, NULL },
   { "ub-pds-parameter-length", 524298, "1"},
   { "extended-network-address", 1342177283, "22"},
   { "ExtendedNetworkAddress", 1610612754, NULL },
   { "e163-4-address", 1610612741, NULL },
-  { "number", 1612718082, "NumericString"},
+  { "number", 1612718108, NULL },
   { NULL, 1073743880, "0"},
   { "ub-e163-4-number-length", 524298, "1"},
-  { "sub-address", 538992642, "NumericString"},
+  { "sub-address", 538992668, NULL },
   { NULL, 1073743880, "1"},
   { "ub-e163-4-sub-address-length", 524298, "1"},
   { "psap-address", 536879106, "PresentationAddress"},
@@ -834,9 +834,9 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "ub-domain-defined-attributes", 1074266122, "1"},
   { NULL, 2, "TeletexDomainDefinedAttribute"},
   { "TeletexDomainDefinedAttribute", 1610612741, NULL },
-  { "type", 1612709890, "TeletexString"},
+  { "type", 1612709918, NULL },
   { "ub-domain-defined-attribute-type-length", 524298, "1"},
-  { "value", 538968066, "TeletexString"},
+  { "value", 538968094, NULL },
   { "ub-domain-defined-attribute-value-length", 524298, "1"},
   { "ub-name", 1342177283, "32768"},
   { "ub-common-name", 1342177283, "64"},
