@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2014 Free Software Foundation, Inc.
+ * Copyright (C) 2002-2013 Free Software Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -44,18 +44,7 @@ extern "C"
 {
 #endif
 
-#define ASN1_VERSION "4.10"
-
-#if defined(__GNUC__) && !defined(ASN1_INTERNAL_BUILD)
-# define _ASN1_GCC_VERSION (__GNUC__ * 10000 + __GNUC_MINOR__ * 100 + __GNUC_PATCHLEVEL__)
-# if _ASN1_GCC_VERSION >= 30100
-#  define _ASN1_GCC_ATTR_DEPRECATED __attribute__ ((__deprecated__))
-# endif
-#endif
-
-#ifndef _ASN1_GCC_ATTR_DEPRECATED
-#define _ASN1_GCC_ATTR_DEPRECATED
-#endif
+#define ASN1_VERSION "3.4"
 
   /*****************************************/
   /* Errors returned by libtasn1 functions */
@@ -184,13 +173,6 @@ extern "C"
 /* makes sure the values are zeroized prior to deinitialization */
 #define ASN1_DELETE_FLAG_ZEROIZE 1
 
-/* Flags used by asn1_der_decoding2(). */
-
-/* This flag would allow arbitrary data past the DER data */
-#define ASN1_DECODE_FLAG_ALLOW_PADDING 1
-/* This flag would ensure that no BER decoding takes place */
-#define ASN1_DECODE_FLAG_STRICT_DER (1<<1)
-
 
   struct asn1_data_node_st
   {
@@ -265,21 +247,15 @@ extern "C"
     asn1_der_coding (asn1_node element, const char *name,
 		     void *ider, int *len, char *ErrorDescription);
 
-  extern ASN1_API int
-    asn1_der_decoding2 (asn1_node *element, const void *ider,
-			int *max_ider_len, unsigned int flags,
-			char *errorDescription);
-
   extern ASN1_API int
     asn1_der_decoding (asn1_node * element, const void *ider,
 		       int len, char *errorDescription);
 
-  /* Do not use. Use asn1_der_decoding() instead. */
   extern ASN1_API int
     asn1_der_decoding_element (asn1_node * structure,
 			       const char *elementName,
 			       const void *ider, int len,
-			       char *errorDescription) _ASN1_GCC_ATTR_DEPRECATED;
+			       char *errorDescription);
 
   extern ASN1_API int
     asn1_der_decoding_startEnd (asn1_node element,
@@ -330,13 +306,6 @@ extern "C"
 				const unsigned char **str,
 				unsigned int *str_len);
 
-  extern ASN1_API
-    int asn1_decode_simple_ber (unsigned int etype, const unsigned char *der,
-				unsigned int der_len,
-				unsigned char **str,
-				unsigned int *str_len,
-				unsigned int *ber_len);
-
   extern ASN1_API int
     asn1_encode_simple_der (unsigned int etype, const unsigned char *str,
 			    unsigned int str_len, unsigned char *tl,
@@ -348,8 +317,6 @@ extern "C"
   extern ASN1_API int
     asn1_copy_node (asn1_node dst, const char *dst_name,
 		    asn1_node src, const char *src_name);
-  extern ASN1_API asn1_node
-    asn1_dup_node (asn1_node src, const char *src_name);
 
   /* Internal and low-level DER utility functions. */
 
@@ -374,11 +341,6 @@ extern "C"
 		      int *ret_len, unsigned char *str,
 		      int str_size, int *bit_len);
 
-  extern ASN1_API int
-    asn1_get_object_id_der (const unsigned char *der,
-                            int der_len, int *ret_len,
-                            char *str, int str_size);
-
 /* Compatibility types */
 
   typedef int asn1_retCode;	/* type returned by libtasn1 functions */
