@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2014 Free Software Foundation, Inc.
+ * Copyright (C) 2002-2013 Free Software Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -183,8 +183,6 @@ asn1_array2tree (const asn1_static_node * array, asn1_node * definitions,
   int result;
   unsigned int type;
 
-  if (errorDescription)
-    errorDescription[0] = 0;
 
   if (*definitions != NULL)
     return ASN1_ELEMENT_NOT_EMPTY;
@@ -425,8 +423,6 @@ _asn1_copy_structure3 (asn1_node source_node)
 	      _asn1_set_down (p_d_prev, p_d);
 	      continue;
 	    }
-	  p_d->start = p_s->start;
-	  p_d->end = p_s->end;
 	}
 
       if (p_s == source_node)
@@ -834,7 +830,7 @@ asn1_print_structure (FILE * out, asn1_node structure, const char *name,
 		  fprintf (out, "  value:0x");
 		  if (len > 0)
 		    for (k = 0; k < len; k++)
-		      fprintf (out, "%02x", (unsigned) (p->value)[k + len2]);
+		      fprintf (out, "%02x", (p->value)[k + len2]);
 		}
 	      break;
 	    case ASN1_ETYPE_ENUMERATED:
@@ -845,7 +841,7 @@ asn1_print_structure (FILE * out, asn1_node structure, const char *name,
 		  fprintf (out, "  value:0x");
 		  if (len > 0)
 		    for (k = 0; k < len; k++)
-		      fprintf (out, "%02x", (unsigned) (p->value)[k + len2]);
+		      fprintf (out, "%02x", (p->value)[k + len2]);
 		}
 	      break;
 	    case ASN1_ETYPE_BOOLEAN:
@@ -867,7 +863,7 @@ asn1_print_structure (FILE * out, asn1_node structure, const char *name,
 		      fprintf (out, "  value(%i):",
 			       (len - 1) * 8 - (p->value[len2]));
 		      for (k = 1; k < len; k++)
-			fprintf (out, "%02x", (unsigned) (p->value)[k + len2]);
+			fprintf (out, "%02x", (p->value)[k + len2]);
 		    }
 		}
 	      break;
@@ -907,7 +903,7 @@ asn1_print_structure (FILE * out, asn1_node structure, const char *name,
 		  fprintf (out, "  value:");
 		  if (len > 0)
 		    for (k = 0; k < len; k++)
-		      fprintf (out, "%02x", (unsigned) (p->value)[k + len2]);
+		      fprintf (out, "%02x", (p->value)[k + len2]);
 		}
 	      break;
 	    case ASN1_ETYPE_OBJECT_ID:
@@ -922,7 +918,7 @@ asn1_print_structure (FILE * out, asn1_node structure, const char *name,
 		  fprintf (out, "  value:");
 		  if (len2 > 0)
 		    for (k = 0; k < len2; k++)
-		      fprintf (out, "%02x", (unsigned) (p->value)[k + len3]);
+		      fprintf (out, "%02x", (p->value)[k + len3]);
 		}
 	      break;
 	    case ASN1_ETYPE_SET:
@@ -1091,17 +1087,18 @@ asn1_number_of_elements (asn1_node element, const char *name, int *num)
 const char *
 asn1_find_structure_from_oid (asn1_node definitions, const char *oidValue)
 {
-  char name[2 * ASN1_MAX_NAME_SIZE + 1];
+  char definitionsName[ASN1_MAX_NAME_SIZE], name[2 * ASN1_MAX_NAME_SIZE + 1];
   char value[ASN1_MAX_NAME_SIZE];
   asn1_node p;
   int len;
   int result;
-  const char *definitionsName;
 
   if ((definitions == NULL) || (oidValue == NULL))
     return NULL;		/* ASN1_ELEMENT_NOT_FOUND; */
 
-  definitionsName = definitions->name;
+
+  strcpy (definitionsName, definitions->name);
+  strcat (definitionsName, ".");
 
   /* search the OBJECT_ID into definitions */
   p = definitions->down;
@@ -1110,7 +1107,8 @@ asn1_find_structure_from_oid (asn1_node definitions, const char *oidValue)
       if ((type_field (p->type) == ASN1_ETYPE_OBJECT_ID) &&
 	  (p->type & CONST_ASSIGN))
 	{
-          snprintf(name, sizeof(name), "%s.%s", definitionsName, p->name);
+	  strcpy (name, definitionsName);
+	  strcat (name, p->name);
 
 	  len = ASN1_MAX_NAME_SIZE;
 	  result = asn1_read_value (definitions, name, value, &len);
@@ -1132,13 +1130,12 @@ asn1_find_structure_from_oid (asn1_node definitions, const char *oidValue)
 
 /**
  * asn1_copy_node:
- * @dst: Destination asn1 node.
+ * @dst: Destination asn1_node node.
  * @dst_name: Field name in destination node.
- * @src: Source asn1 node.
+ * @src: Source asn1_node node.
  * @src_name: Field name in source node.
  *
- * Create a deep copy of a asn1_node variable. That
- * function requires @dst to be expanded using asn1_create_element().
+ * Create a deep copy of a asn1_node variable.
  *
  * Returns: Return %ASN1_SUCCESS on success.
  **/
@@ -1146,6 +1143,9 @@ int
 asn1_copy_node (asn1_node dst, const char *dst_name,
 		asn1_node src, const char *src_name)
 {
+/* FIXME: rewrite using copy_structure().
+ * It seems quite hard to do.
+ */
   int result;
   asn1_node dst_node;
   void *data = NULL;
@@ -1179,19 +1179,3 @@ asn1_copy_node (asn1_node dst, const char *dst_name,
 
   return result;
 }
-
-/**
- * asn1_dup_node:
- * @src: Source asn1 node.
- * @src_name: Field name in source node.
- *
- * Create a deep copy of a asn1_node variable. This function
- * will return an exact copy of the provided structure.
- *
- * Returns: Return %NULL on failure.
- **/
-asn1_node
-asn1_dup_node (asn1_node src, const char *src_name)
-{
-  return _asn1_copy_structure2(src, src_name);
-}
