@@ -1,5 +1,5 @@
 /* asn1Coding.c --- program to generate a DER coding of an ASN1 definition.
- * Copyright (C) 2002-2021 Free Software Foundation, Inc.
+ * Copyright (C) 2002-2013 Free Software Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -25,11 +25,11 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <getopt.h>
-#include <assert.h>
 
 #include <libtasn1.h>
 
-#define program_name "asn1Coding"
+#include <progname.h>
+#include <version-etc.h>
 
 /* This feature is available in gcc versions 2.5 and later.  */
 #if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 5)
@@ -57,7 +57,7 @@ Mandatory arguments to long options are mandatory for short options too.\n\
   -o, --output=FILE     output file\n\
   -h, --help            display this help and exit\n\
   -v, --version         output version information and exit\n");
-     printf ("Report bugs to "PACKAGE_BUGREPORT);
+      emit_bug_reporting_address ();
     }
   exit (status);
 }
@@ -72,13 +72,13 @@ readAssignment (FILE * file, char *varName, char *value)
 
   int ret;
 
-  ret = fscanf (file, "%1023s", varName);
+  ret = fscanf (file, "%s", varName);
   if (ret == EOF)
     return ASSIGNMENT_EOF;
   if (!strcmp (varName, "''"))
     varName[0] = 0;
 
-  ret = fscanf (file, "%1023s", value);
+  ret = fscanf (file, "%s", value);
   if (ret == EOF)
     return ASSIGNMENT_ERROR;
 
@@ -111,12 +111,6 @@ createFileName (char *inputFileName, char **outputFileName)
   /* outputFileName= inputFileName + .out */
   *outputFileName = (char *) malloc (dot_p - inputFileName + 1 +
 				     strlen (".out"));
-  if (*outputFileName == NULL)
-    {
-      fprintf(stderr, "Memory error\n");
-      exit(1);
-    }
-
   memcpy (*outputFileName, inputFileName, dot_p - inputFileName);
   (*outputFileName)[dot_p - inputFileName] = 0;
   strcat (*outputFileName, ".out");
@@ -152,6 +146,8 @@ main (int argc, char *argv[])
   int k;
   int last_ra;
 
+  set_program_name (argv[0]);
+
   opterr = 0;			/* disable error messages from getopt */
 
   while (1)
@@ -170,9 +166,8 @@ main (int argc, char *argv[])
 	  usage (EXIT_SUCCESS);
 	  break;
 	case 'v':		/* VERSION */
-	  printf(program_name" "PACKAGE" " VERSION"\n");
-	  printf("Copyright (C) 2017-2021 Free Software Foundation, Inc.\n\n");
-	  printf("Written by Fabio Fiorina\n");
+	  version_etc (stdout, program_name, PACKAGE, VERSION,
+		       "Fabio Fiorina", NULL);
 	  free (outputFileName);
 	  exit (0);
 	  break;
@@ -180,13 +175,8 @@ main (int argc, char *argv[])
 	  checkSyntaxOnly = 1;
 	  break;
 	case 'o':		/* OUTPUT */
-	  assert(optarg != NULL);
-	  outputFileName = strdup(optarg);
-	  if (outputFileName == NULL)
-	    {
-	      fprintf(stderr, "Memory error\n");
-	      exit(1);
-	    }
+	  outputFileName = (char *) malloc (strlen (optarg) + 1);
+	  strcpy (outputFileName, optarg);
 	  break;
 	case '?':		/* UNKNOW OPTION */
 	  free (outputFileName);
@@ -198,7 +188,7 @@ main (int argc, char *argv[])
 	default:
 	  fprintf (stderr,
 		   "asn1Coding: ?? getopt returned character code Ox%x ??\n",
-		   (unsigned)option_result);
+		   option_result);
 	}
     }
 
@@ -209,19 +199,11 @@ main (int argc, char *argv[])
       usage (EXIT_FAILURE);
     }
 
-  inputFileAsnName = strdup(argv[optind]);
-  if (inputFileAsnName == NULL)
-    {
-      fprintf(stderr, "Memory error\n");
-      exit(1);
-    }
+  inputFileAsnName = (char *) malloc (strlen (argv[optind]) + 1);
+  strcpy (inputFileAsnName, argv[optind]);
 
-  inputFileAssignmentName = strdup(argv[optind+1]);
-  if (inputFileAssignmentName == NULL)
-    {
-      fprintf(stderr, "Memory error\n");
-      exit(1);
-    }
+  inputFileAssignmentName = (char *) malloc (strlen (argv[optind + 1]) + 1);
+  strcpy (inputFileAssignmentName, argv[optind + 1]);
 
   asn1_result =
     asn1_parser2tree (inputFileAsnName, &definitions, errorDescription);
@@ -274,12 +256,7 @@ main (int argc, char *argv[])
 	  asn1_result = asn1_create_element (definitions, value, &structure);
 	}
       else
-        {
-	  if (strcmp(value, "(NULL)") == 0)
-	    asn1_result = asn1_write_value (structure, varName, NULL, 0);
-	  else
-	    asn1_result = asn1_write_value (structure, varName, value, 0);
-	}
+	asn1_result = asn1_write_value (structure, varName, value, 0);
 
       if (asn1_result != ASN1_SUCCESS)
 	{
@@ -307,16 +284,11 @@ main (int argc, char *argv[])
   asn1_print_structure (stderr, structure, "", ASN1_PRINT_NAME_TYPE_VALUE);
 
   der_len = 0;
-  asn1_result = asn1_der_coding (structure, "", NULL, &der_len,
+  asn1_result = asn1_der_coding (structure, "", der, &der_len,
 				 errorDescription);
   if (asn1_result == ASN1_MEM_ERROR)
     {
       der = malloc (der_len);
-      if (der == NULL)
-        {
-          fprintf(stderr, "Memory error\n");
-          exit(1);
-        }
       asn1_result = asn1_der_coding (structure, "", der, &der_len,
 				     errorDescription);
     }
