@@ -1,5 +1,5 @@
 /* asn1Decoding.c ---  program to generate an ASN1 type from a DER coding.
- * Copyright (C) 2002-2021 Free Software Foundation, Inc.
+ * Copyright (C) 2002-2013 Free Software Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -25,17 +25,16 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <getopt.h>
-#include <sys/types.h>
-#include <sys/stat.h>
 
 #include <libtasn1.h>
 
+#include <progname.h>
+#include <version-etc.h>
+#include <read-file.h>
 #include "benchmark.h"
 
-#define program_name "asn1Decoding"
-
 static int decode (asn1_node definitions, const char *typeName, void *der,
-		   int der_len, int benchmark, int strict);
+		   int der_len, int benchmark);
 
 /* This feature is available in gcc versions 2.5 and later.  */
 #if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 5)
@@ -58,65 +57,18 @@ Decodes DER data in ENCODED file, for the ASN1TYPE element\n\
 described in ASN.1 DEFINITIONS file, and print decoded structures.\n\
 \n");
       printf ("\
-  -b, --benchmark       perform a benchmark on decoding\n\
-  -s, --strict          use strict DER decoding\n\
-  -t, --no-time-strict  use strict DER decoding but not in time fields\n\
   -h, --help            display this help and exit\n\
   -v, --version         output version information and exit\n");
-     printf ("Report bugs to "PACKAGE_BUGREPORT);
+      emit_bug_reporting_address ();
     }
   exit (status);
 }
 
-static char *read_binary_file(const char *file, size_t *l)
-{
-  FILE *fp;
-  struct stat st;
-  char *out;
-
-  if (stat(file, &st) == -1)
-    {
-      fprintf(stderr, "Error reading file size!\n");
-      exit(1);
-    }
-
-  fp = fopen(file, "rb");
-  if (fp == NULL)
-    {
-      fprintf(stderr, "Error reading file!\n");
-      exit(1);
-    }
-
-  out = malloc(st.st_size+1);
-  if (out == NULL)
-    {
-      fprintf(stderr, "Memory error!\n");
-      exit(1);
-    }
-
-  *l = fread(out, 1, st.st_size, fp);
-  if ((off_t)*l != st.st_size)
-    {
-      fprintf(stderr, "Error reading contents (got: %ld, expected %ld)!\n",
-              (long)*l, (long)st.st_size);
-      exit(1);
-    }
-
-  out[*l] = 0;
-
-  fclose(fp);
-  return out;
-}
-
 int
 main (int argc, char *argv[])
 {
   static const struct option long_options[] = {
     {"help", no_argument, 0, 'h'},
-    {"strict", no_argument, 0, 's'},
-    {"no-time-strict", no_argument, 0, 't'},
-    {"debug", no_argument, 0, 'd'},
-    {"benchmark", no_argument, 0, 'b'},
     {"version", no_argument, 0, 'v'},
     {0, 0, 0, 0}
   };
@@ -130,16 +82,17 @@ main (int argc, char *argv[])
   int asn1_result = ASN1_SUCCESS;
   unsigned char *der;
   int der_len = 0, benchmark = 0;
-  int flags = 0, debug = 0;
   /* FILE *outputFile; */
 
+  set_program_name (argv[0]);
+
   opterr = 0;			/* disable error messages from getopt */
 
   while (1)
     {
 
       option_result =
-	getopt_long (argc, argv, "hbdsvtc", long_options, &option_index);
+	getopt_long (argc, argv, "hbvc", long_options, &option_index);
 
       if (option_result == -1)
 	break;
@@ -152,19 +105,9 @@ main (int argc, char *argv[])
 	case 'b':
 	  benchmark = 1;
 	  break;
-	case 'd':
-	  debug = 1;
-	  break;
-	case 's':
-	case 't':
-	  flags |= ASN1_DECODE_FLAG_STRICT_DER;
-	  if (option_result == 't')
-	    flags |= ASN1_DECODE_FLAG_ALLOW_INCORRECT_TIME;
-	  break;
 	case 'v':		/* VERSION */
-	  printf(program_name" "PACKAGE" " VERSION"\n");
-	  printf("Copyright (C) 2017-2021 Free Software Foundation, Inc.\n\n");
-	  printf("Written by Fabio Fiorina\n");
+	  version_etc (stdout, program_name, PACKAGE, VERSION,
+		       "Fabio Fiorina", NULL);
 	  exit (0);
 	  break;
 	case '?':		/* UNKNOW OPTION */
@@ -176,7 +119,7 @@ main (int argc, char *argv[])
 	default:
 	  fprintf (stderr,
 		   "asn1Decoding: ?? getopt returned character code Ox%x ??\n",
-		   (unsigned)option_result);
+		   option_result);
 	}
     }
 
@@ -187,18 +130,14 @@ main (int argc, char *argv[])
       usage (EXIT_FAILURE);
     }
 
-  inputFileAsnName = strdup(argv[optind]);
-  inputFileDerName = strdup(argv[optind + 1]);
-  typeName = strdup(argv[optind + 2]);
+  inputFileAsnName = (char *) malloc (strlen (argv[optind]) + 1);
+  strcpy (inputFileAsnName, argv[optind]);
 
-  if (!(inputFileAsnName && inputFileDerName && typeName))
-    {
-      fprintf(stderr, "allocation failed\n");
-      free(inputFileAsnName);
-      free(inputFileDerName);
-      free(typeName);
-      exit(1);
-    }
+  inputFileDerName = (char *) malloc (strlen (argv[optind + 1]) + 1);
+  strcpy (inputFileDerName, argv[optind + 1]);
+
+  typeName = (char *) malloc (strlen (argv[optind + 2]) + 1);
+  strcpy (typeName, argv[optind + 2]);
 
   asn1_result =
     asn1_parser2tree (inputFileAsnName, &definitions, errorDescription);
@@ -235,12 +174,6 @@ main (int argc, char *argv[])
     der_len = tmplen;
   }
 
-  /* read_binary_file() returns a buffer with more data than required,
-   * with this reallocation we ensure that memory accesses outside the
-   * boundaries are detected */
-  if (der != NULL && debug != 0)
-    der = realloc(der, der_len);
-
   if (der == NULL)
     {
       fprintf (stderr, "asn1Decoding: could not read '%s'\n",
@@ -253,14 +186,14 @@ main (int argc, char *argv[])
       exit (1);
     }
 
+
  /*****************************************/
   /* ONLY FOR TEST                         */
  /*****************************************/
   /*
      der_len=0;
      outputFile=fopen("data.p12","w");
-     while(fscanf(inputFile,"%c",der+der_len) != EOF)
-     {
+     while(fscanf(inputFile,"%c",der+der_len) != EOF){
      if((der_len>=0x11) && (der_len<=(0xe70)))
      fprintf(outputFile,"%c",der[der_len]);
      der_len++;
@@ -269,7 +202,7 @@ main (int argc, char *argv[])
      fclose(inputFile);
    */
 
-  if (decode (definitions, typeName, der, der_len, benchmark, flags) != ASN1_SUCCESS)
+  if (decode (definitions, typeName, der, der_len, benchmark) != ASN1_SUCCESS)
     {
       asn1_delete_structure (&definitions);
       free (inputFileAsnName);
@@ -295,7 +228,7 @@ main (int argc, char *argv[])
 
 static int
 simple_decode (asn1_node definitions, const char *typeName, void *der,
-	       int der_len, int benchmark, int flags)
+	       int der_len, int benchmark)
 {
 
   int asn1_result;
@@ -315,12 +248,8 @@ simple_decode (asn1_node definitions, const char *typeName, void *der,
       return asn1_result;
     }
 
-  if (flags != 0)
-    asn1_result =
-      asn1_der_decoding2(&structure, der, &der_len, flags, errorDescription);
-  else
-    asn1_result =
-      asn1_der_decoding (&structure, der, der_len, errorDescription);
+  asn1_result =
+    asn1_der_decoding (&structure, der, der_len, errorDescription);
 
   if (!benchmark)
     fprintf (stderr, "\nDecoding: %s\n", asn1_strerror (asn1_result));
@@ -343,19 +272,19 @@ simple_decode (asn1_node definitions, const char *typeName, void *der,
 
 static int
 decode (asn1_node definitions, const char *typeName, void *der, int der_len,
-	int benchmark, int flags)
+	int benchmark)
 {
   struct benchmark_st st;
 
   if (benchmark == 0)
-    return simple_decode (definitions, typeName, der, der_len, benchmark, flags);
+    return simple_decode (definitions, typeName, der, der_len, benchmark);
   else
     {
       start_benchmark (&st);
 
       do
 	{
-	  simple_decode (definitions, typeName, der, der_len, benchmark, flags);
+	  simple_decode (definitions, typeName, der, der_len, benchmark);
 	  st.size++;
 	}
       while (benchmark_must_finish == 0);
