@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 Free Software Foundation, Inc.
+ * Copyright (C) 2002-2013 Free Software Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -33,8 +33,6 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-
-#define ASN1_INTERNAL_BUILD
 #include "libtasn1.h"
 
 #include "Test_tree_asn1_tab.c"
@@ -86,7 +84,6 @@ test_type test_array[] = {
   {ACT_ENCODING, "", 0, 4, ASN1_MEM_ERROR, __LINE__},
   {ACT_ENCODING, "", 0, 5, ASN1_SUCCESS, __LINE__},
   {ACT_PRINT_DER, 0, 0, 0, ASN1_SUCCESS, __LINE__},
-  {ACT_DELETE, "", "", 0, ASN1_SUCCESS, __LINE__},
   {ACT_CREATE, "TEST_TREE.KrbError", 0, 0, ASN1_SUCCESS, __LINE__},
   {ACT_DECODING, 0, 0, 0, ASN1_SUCCESS, __LINE__},
   {ACT_VISIT, "", "", ASN1_PRINT_ALL, ASN1_SUCCESS, __LINE__},
@@ -401,13 +398,11 @@ test_type test_array[] = {
   {ACT_ENCODING, "", 0, 24, ASN1_MEM_ERROR, __LINE__},
   {ACT_ENCODING, "", 0, 25, ASN1_SUCCESS, __LINE__},
   {ACT_PRINT_DER, 0, 0, 0, ASN1_SUCCESS, __LINE__},
-  {ACT_DELETE, "", "", 0, ASN1_SUCCESS, __LINE__},
   {ACT_CREATE, "TEST_TREE.Sequence1", 0, 0, ASN1_SUCCESS, __LINE__},
   {ACT_DECODING_ELEMENT, "int2", 0, 0, ASN1_SUCCESS, __LINE__},
   {ACT_VISIT, "", "", ASN1_PRINT_ALL, ASN1_SUCCESS, __LINE__},
   {ACT_READ, "int2", "\x0a", 1, ASN1_SUCCESS, __LINE__},
   {ACT_READ_LENGTH, "int2", NULL, 1, ASN1_MEM_ERROR, __LINE__},
-  {ACT_DELETE, "", "", 0, ASN1_SUCCESS, __LINE__},
   {ACT_CREATE, "TEST_TREE.Sequence1", 0, 0, ASN1_SUCCESS, __LINE__},
   {ACT_DECODING, 0, 0, 0, ASN1_SUCCESS, __LINE__},
   {ACT_DECODING_START_END, "seq.?2", "START", 10, ASN1_SUCCESS, __LINE__},
@@ -539,8 +534,7 @@ main (int argc, char *argv[])
 	  result = asn1_delete_structure (&asn1_element);
 	  break;
 	case ACT_DELETE2:
-	  result =
-	    asn1_delete_structure2 (&asn1_element, ASN1_DELETE_FLAG_ZEROIZE);
+	  result = asn1_delete_structure2 (&asn1_element, ASN1_DELETE_FLAG_ZEROIZE);
 	  break;
 	case ACT_DELETE_ELEMENT:
 	  result = asn1_delete_element (asn1_element, test->par1);
@@ -791,7 +785,7 @@ main (int argc, char *argv[])
 	      printf ("  Error expected: %s - %d - ",
 		      asn1_strerror (test->errorNumber), test->par3);
 	      for (k = 0; k < test->par3; k++)
-		printf ("%02x", (unsigned int) test->par2[k]);
+		printf ("%02x", test->par2[k]);
 	      printf ("\n  Error detected: %s - %d - ",
 		      asn1_strerror (result), valueLen);
 	      for (k = 0; k < valueLen; k++)
